summaryrefslogtreecommitdiff
path: root/test/files/run/typed-annotated/Macros_1.scala
diff options
context:
space:
mode:
Diffstat (limited to 'test/files/run/typed-annotated/Macros_1.scala')
-rw-r--r--test/files/run/typed-annotated/Macros_1.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/files/run/typed-annotated/Macros_1.scala b/test/files/run/typed-annotated/Macros_1.scala
index d805d82f39..4f0660dc45 100644
--- a/test/files/run/typed-annotated/Macros_1.scala
+++ b/test/files/run/typed-annotated/Macros_1.scala
@@ -6,8 +6,8 @@ class ann extends scala.annotation.StaticAnnotation
object Macros {
def impl(c: Context) = {
import c.universe._
- // val tpt = Annotated(Apply(Select(New(Ident(newTypeName("ann"))), nme.CONSTRUCTOR), List()), Ident(newTypeName("Int")))
- val tpt = Annotated(Apply(Select(New(Ident(newTypeName("ann"))), nme.CONSTRUCTOR), List()), TypeTree(weakTypeOf[Int]))
+ // val tpt = Annotated(Apply(Select(New(Ident(newTypeName("ann"))), termNames.CONSTRUCTOR), List()), Ident(newTypeName("Int")))
+ val tpt = Annotated(Apply(Select(New(Ident(newTypeName("ann"))), termNames.CONSTRUCTOR), List()), TypeTree(weakTypeOf[Int]))
c.Expr[Unit](Block(
List(ValDef(Modifiers(), newTermName("x"), tpt, Literal(Constant(42)))),
Apply(Ident(newTermName("println")), List(Ident(newTermName("x"))))))